@@ -28,6 +28,7 @@ doJobCollection = function(jc, output = NULL) {
 #' @export
 doJobCollection.character = function(jc, output = NULL) {
   obj = readRDS(jc)
+  force(obj)
   if (!batchtools$debug && !obj$array.jobs)
     file.remove(jc)
   doJobCollection.JobCollection(obj, output = output)
@@ -43,16 +44,12 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
     updates = data.table(job.id = jc$jobs$job.id, started = now, done = now,
       error = stri_trunc(stri_trim_both(sprintf(msg, ...)), 500L, " [truncated]"),
       memory = NA_real_, key = "job.id")
-    writeRDS(updates, file = file.path(jc$file.dir, "updates", sprintf("%s.rds", jc$job.hash)))
+    writeRDS(updates, file = fp(jc$file.dir, "updates", sprintf("%s.rds", jc$job.hash)))
     invisible(NULL)
   }
 
   # signal warnings immediately
-  warn = getOption("warn")
-  if (!identical(warn, 1L)) {
-    on.exit(options(warn = warn))
-    options(warn = 1L)
-  }
+  local_options(c(warn = 1L))
 
   # setup output connection
   if (!is.null(output)) {
@@ -82,13 +79,11 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
   # set work dir
   if (!dir.exists(jc$work.dir))
     return(error("Work dir does not exist"))
-  prev.wd = getwd()
-  setwd(jc$work.dir)
-  on.exit(setwd(prev.wd), add = TRUE)
+  local_dir(jc$work.dir)
 
   # load registry dependencies: packages, source files, ...
   # note that this should happen _before_ parallelMap is initialized
-  ok = try(loadRegistryDependencies(jc, switch.wd = FALSE), silent = TRUE)
+  ok = try(loadRegistryDependencies(jc, must.work = TRUE), silent = TRUE)
   if (is.error(ok))
     return(error("Error loading registry dependencies: %s", as.character(ok)))
 
@@ -108,13 +103,13 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
   catf("### [bt %s]: Memory measurement %s", s, ifelse(measure.memory, "enabled", "disabled"))
 
   # try to pre-fetch some objects from the file system
-  cache = Cache$new(jc$file.dir)
+  reader = RDSReader$new(n.jobs > 1L)
   buf = UpdateBuffer$new(jc$jobs$job.id)
 
-  runHook(jc, "pre.do.collection", cache = cache)
+  runHook(jc, "pre.do.collection", reader = reader)
 
   for (i in seq_len(n.jobs)) {
-    job = getJob(jc, i, cache = cache)
+    job = getJob(jc, i, reader = reader)
     id = job$id
 
     update = list(started = ustamp(), done = NA_integer_, error = NA_character_, memory = NA_real_)
@@ -139,7 +134,7 @@ doJobCollection.JobCollection = function(jc, output = NULL) {
     buf$flush(jc)
   }
 
-  runHook(jc, "post.do.collection", updates = buf$updates, cache = cache)
+  runHook(jc, "post.do.collection", updates = buf$updates, reader = reader)
   buf$save(jc)
   catf("### [bt %s]: Calculation finished!", now())
 
@@ -154,7 +149,7 @@ UpdateBuffer = R6Class("UpdateBuffer",
     next.update = NA_real_,
     initialize = function(ids) {
       self$updates = data.table(job.id = ids, started = NA_real_, done = NA_real_, error = NA_character_, memory = NA_real_, written = FALSE, key = "job.id")
-      self$next.update = Sys.time() + runif(1L, 300, 1800)
+      self$next.update = Sys.time() + runif(1L, 60, 300)
     },
 
     add = function(i, x) {
@@ -165,7 +160,7 @@ UpdateBuffer = R6Class("UpdateBuffer",
       i = self$updates[!is.na(started) & (!written), which = TRUE]
       if (length(i) > 0L) {
         first.id = self$updates$job.id[i[1L]]
-        writeRDS(self$updates[i], file = file.path(jc$file.dir, "updates", sprintf("%s-%i.rds", jc$job.hash, first.id)))
+        writeRDS(self$updates[i], file = fp(jc$file.dir, "updates", sprintf("%s-%i.rds", jc$job.hash, first.id)))
         set(self$updates, i, "written", TRUE)
       }
     },
@@ -174,7 +169,7 @@ UpdateBuffer = R6Class("UpdateBuffer",
       now = Sys.time()
       if (now > self$next.update) {
         self$save(jc)
-        self$next.update = now + runif(1L, 300, 1800)
+        self$next.update = now + runif(1L, 60, 300)
       }
     }
 
