@@ -15,7 +15,7 @@ saveRegistry = function(reg = getDefaultRegistry()) {
   if (reg$writeable) {
     "!DEBUG [saveRegistry]: Saving Registry"
 
-    fn = file.path(reg$file.dir, c("registry.new.rds", "registry.rds"))
+    fn = fp(reg$file.dir, c("registry.new.rds", "registry.rds"))
     ee = new.env(parent = asNamespace("batchtools"))
     list2env(mget(chsetdiff(ls(reg), c("cluster.functions", "default.resources", "temp.dir")), reg), ee)
     class(ee) = class(reg)
