@@ -5,8 +5,9 @@
 #'
 #' @templateVar ids.default findSubmitted
 #' @template ids
-#' @param sleep [\code{numeric(1)}]\cr
-#'   Seconds to sleep between status updates. Default is \code{10}.
+#' @param sleep [\code{function(i)} | \code{numeric(1)}]\cr
+#'   Function which returns the duration to sleep in the \code{i}-th iteration.
+#'   Alternatively, you can pass a single positive numeric value.
 #' @param timeout [\code{numeric(1)}]\cr
 #'   After waiting \code{timeout} seconds, show a message and return
 #'   \code{FALSE}. This argument may be required on some systems where, e.g.,
@@ -20,16 +21,16 @@
 #'   successfully and \code{FALSE} if either the timeout is reached or at least
 #'   one job terminated with an exception.
 #' @export
-waitForJobs = function(ids = NULL, sleep = 10, timeout = 604800, stop.on.error = FALSE, reg = getDefaultRegistry()) {
+waitForJobs = function(ids = NULL, sleep = default.sleep, timeout = 604800, stop.on.error = FALSE, reg = getDefaultRegistry()) {
   assertRegistry(reg, writeable = FALSE, sync = TRUE)
-  assertNumeric(sleep, len = 1L, lower = 0.2, finite = TRUE)
-  assertNumeric(timeout, len = 1L, lower = sleep)
+  assertNumber(timeout, lower = 0)
   assertFlag(stop.on.error)
+  sleep = getSleepFunction(sleep)
   ids = convertIds(reg, ids, default = .findSubmitted(reg = reg))
 
   .findNotTerminated = function(reg, ids = NULL) {
     done = NULL
-    filter(reg$status, ids, c("job.id", "done"))[is.na(done), "job.id", with = FALSE]
+    filter(reg$status, ids, c("job.id", "done"))[is.na(done), "job.id"]
   }
 
   if (nrow(.findNotSubmitted(ids = ids, reg = reg)) > 0L) {
@@ -37,37 +38,41 @@ waitForJobs = function(ids = NULL, sleep = 10, timeout = 604800, stop.on.error =
     ids = ids[.findSubmitted(ids = ids, reg = reg), nomatch = 0L]
   }
 
-  n.jobs.total = n.jobs = nrow(ids)
+  n.jobs = nrow(ids)
   if (n.jobs == 0L)
     return(TRUE)
 
   batch.ids = getBatchIds(reg)
-  if (nrow(batch.ids) == 0L)
-    return(nrow(.findErrors(reg, ids)) == 0L)
+  "!DEBUG [waitForJobs]: Using `nrow(ids)` ids and `nrow(batch.ids)` initial batch ids"
 
-  timeout = ustamp() + timeout
+  timeout = Sys.time() + timeout
   ids.disappeared = noIds()
-
-  pb = makeProgressBar(total = n.jobs.total, format = "Waiting (S::system R::running D::done E::error) [:bar] :percent eta: :eta",
-    tokens = as.list(getStatusTable(ids, batch.ids, reg = reg)))
+  pb = makeProgressBar(total = n.jobs, format = "Waiting (S::system R::running D::done E::error) [:bar] :percent eta: :eta")
+  i = 1L
 
   repeat {
     # case 1: all jobs terminated -> nothing on system
     ids.nt = .findNotTerminated(reg, ids)
     if (nrow(ids.nt) == 0L) {
-      pb$tick(n.jobs.total)
+      "!DEBUG [waitForJobs]: All jobs terminated"
+      pb$update(1)
+      waitForResults(reg, ids)
       return(nrow(.findErrors(reg, ids)) == 0L)
     }
 
+    stats = getStatusTable(ids = ids, batch.ids = batch.ids, reg = reg)
+    pb$update((n.jobs - nrow(ids.nt)) / n.jobs, tokens = as.list(stats))
+
     # case 2: there are errors and stop.on.error is TRUE
     if (stop.on.error && nrow(.findErrors(reg, ids)) > 0L) {
-      pb$tick(n.jobs.total)
+      "!DEBUG [waitForJobs]: Errors found and stop.on.error is TRUE"
+      pb$update(1)
       return(FALSE)
     }
 
     # case 3: we have reached a timeout
-    if (ustamp() > timeout) {
-      pb$tick(n.jobs.total)
+    if (Sys.time() > timeout) {
+      pb$update(1)
       warning("Timeout reached")
       return(FALSE)
     }
@@ -80,18 +85,19 @@ waitForJobs = function(ids = NULL, sleep = 10, timeout = 604800, stop.on.error =
     if (nrow(ids.disappeared) > 0L) {
       if (nrow(ids.nt[!ids.on.sys, on = "job.id"][ids.disappeared, on = "job.id", nomatch = 0L]) > 0L) {
         warning("Some jobs disappeared from the system")
-        pb$tick(n.jobs.total)
+        pb$update(1)
+        waitForResults(reg, ids)
         return(FALSE)
       }
     }
+
     ids.disappeared = ids[!ids.on.sys, on = "job.id"]
+    "!DEBUG [waitForJobs]: `nrow(ids.disappeared)` jobs disappeared"
 
-    stats = getStatusTable(ids = ids, batch.ids = batch.ids, reg = reg)
-    pb$tick(n.jobs - nrow(ids.nt), tokens = as.list(stats))
-    n.jobs = nrow(ids.nt) # FIXME: remove after progress is updated
-
-    Sys.sleep(sleep)
+    sleep(i)
+    i = 1 + 1L
     suppressMessages(syncRegistry(reg = reg))
     batch.ids = getBatchIds(reg)
+    "!DEBUG [waitForJobs]: New batch.ids: `stri_flatten(batch.ids$batch.id, ',')`"
   }
 }
