@@ -7,8 +7,8 @@ test_that("makeExperimentRegistry", {
   expect_true(is.environment(reg))
   expect_directory(reg$file.dir, access = "rw")
   expect_directory(reg$work.dir, access = "r")
-  expect_directory(file.path(reg$file.dir, c("jobs", "results", "updates", "logs")))
-  expect_file(file.path(reg$file.dir, "registry.rds"))
+  expect_directory(fp(reg$file.dir, c("jobs", "results", "updates", "logs")))
+  expect_file(fp(reg$file.dir, "registry.rds"))
   expect_character(reg$packages, any.missing = FALSE)
   expect_character(reg$namespaces, any.missing = FALSE)
   expect_int(reg$seed, na.ok = FALSE)
