@@ -6,13 +6,13 @@ test_that("hooks", {
     skip("Hooks already defined by Cluster Functions")
   reg$cluster.functions$hooks = insert(reg$cluster.functions$hooks, list(
     "pre.do.collection" = function(jc, ...) cat(jc$job.hash, "\n", sep = ""),
-    "post.sync" = function(reg, ...) cat("post.syn", file = file.path(reg$file.dir, "post.sync.txt"))
+    "post.sync" = function(reg, ...) cat("post.syn", file = fp(reg$file.dir, "post.sync.txt"))
   ))
 
   jc = makeJobCollection(1, reg = reg)
   expect_function(jc$hooks$pre.do.collection, args = "jc")
 
-  fn.ps = file.path(reg$file.dir, "post.sync.txt")
+  fn.ps = fp(reg$file.dir, "post.sync.txt")
   expect_false(file.exists(fn.ps))
 
   batchMap(identity, 1, reg = reg)
